# LoggingScalyrAdditional


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**region** | **str** | The region that log data will be sent to. | [optional]  if omitted the server will use the default value of "US"
**token** | **str** | The token to use for authentication ([https://www.scalyr.com/keys](https://www.scalyr.com/keys)). | [optional] 
**project_id** | **str** | The name of the logfile within Scalyr. | [optional]  if omitted the server will use the default value of "logplex"
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


